#
# spec file for package pfstools
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _libname libpfs2
Name:           pfstools
Version:        2.1.0
Release:        lp152.3.4
Summary:        High Dynamic Range Image and Video manipulation tools
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            http://pfstools.sourceforge.net/
Source:         https://sourceforge.net/projects/pfstools/files/pfstools/%{version}/%{name}-%{version}.tgz
Patch1:         %{name}-gcc.patch
Patch2:         pfstools-octinstall.patch
Patch3:         pfstools-stdlib.patch
Patch4:         pfstools-1.8.1-fix-return-in-nonvoid.patch
# PATCH-FIX-OPENSUSE - https://sourceforge.net/p/pfstools/bugs/45/
Patch5:         pfstools-fix-libpfs-linkage.patch
# patch derived from https://github.com/pld-linux/pfstools/commit/67bd2304e516545f2b203f975ac5dd30d2b479b3
# I guess it could go upstream as is; sent email to mantiuk at gmail
Patch7:         pfstools-ImageMagick7.patch
BuildRequires:  Mesa
BuildRequires:  blas
# previous versions of cmake don't support ImageMagick 7
BuildRequires:  cmake >= 3.9.0
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  fftw3-threads-devel
BuildRequires:  freeglut-devel
BuildRequires:  hdf5-devel
BuildRequires:  lapack
BuildRequires:  libnetpbm-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(Magick++)
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(octave)
Requires:       dcraw

%description
The pfstools package is a set of command line (and one GUI) programs
for reading, writing, manipulating and viewing high-dynamic range
(HDR) images and video frames. All programs in the package exchange
data using the pfs file format for HDR data. The concept of pfstools
is similar to netpbm for low-dynamic range images.

%package -n %{_libname}
Summary:        Library for HDR image and video manipulation
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{_libname}
The pfstools package is a set of command line (and one GUI) programs
for reading, writing, manipulating and viewing high-dynamic range
(HDR) images and video frames. All programs in the package exchange
data using the pfs file format for HDR data. The concept of pfstools
is similar to netpbm for low-dynamic range images.

#Disable until opencv can be enabled.
#%%package -n pfscalign
#Summary:        Align image stack
#License:        GPL-2.0+ and LGPL-2.1+
#Group:          Productivity/Multimedia/Other

#%%description -n pfscalign
#Align multiple exposures using homographic transformation. The command
#uses a similar feature-point based method as most panorama stitching software.

%package -n pfscalibration
Summary:        Photometric Calibration of HDR and LDR Cameras
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
Requires:       dcraw
Requires:       jhead
%{perl_requires}
%{?libperl_requires}

%description -n pfscalibration
A photographic camera with a standard CCD sensor is able to acquire an
image with simultaneous dynamic range of not more than 1:1000. The
basic idea to create an image with a higher dynamic range is to combine
multiple images with different exposure settings, thus making use of
available sequential dynamic range.

%package -n pfstmo
Summary:        Tone Mapping Operators for High Dynamic Range Images
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other

%description -n pfstmo
pfstmo package contains the implementation of tone mapping operators,
suitable for processing of both static images and animations.

%package -n pfsview
Summary:        Qt-based viewer for HDR files
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other

%description -n pfsview
pfsview is a viewer program based on Qt4 for viewing HDR graphic files.

%package -n pfsglview
Summary:        GL-based viewer for HDR files
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other

%description -n pfsglview
pfsglview is a viewer program based on OpenGL for viewing HDR graphic files.

%package exr
Summary:        EXR file import and export for PFS tools
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other

%description exr
This package contains two-way conversion filters between the EXR file
format and pfstools's HDR graphics file format.

%package imgmagick
Summary:        ImageMagick file import for PFS tools
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other

%description imgmagick
This package contains input and output filters for ImageMagick to
support pfstools's HDR graphics file format.

%package octave
Summary:        Octave interaction with PFS tools
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
Requires:       octave

%description octave
The pfstools-octave package contains programs to process RGB
or luminance channels in PFS streams using Octave.

%package devel
Summary:        Development files for libpfs, a library for HDR image and video manipulation
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %{_libname} = %{version}

%description devel
The pfstools package is a set of command line (and one GUI) programs
for reading, writing, manipulating and viewing high-dynamic range
(HDR) images and video frames.

This subpackage contains libraries and header files for developing
applications that want to make use of libpfs.

%prep
%autosetup -p1
chmod -x ChangeLog

%build
%cmake
make %{?_smp_mflags}

%install
cd build
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
grep -r include %{buildroot}%{_includedir} | awk -F: '{print $2}'
%fdupes -s %{buildroot}%{_mandir}

%post -n %{_libname} -p /sbin/ldconfig
%postun -n %{_libname} -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS ChangeLog README doc/faq.txt
%dir %{_datadir}/%{name}
%{_bindir}/pfsabsolute
%{_bindir}/pfscat
%{_bindir}/pfsclamp
%{_bindir}/pfscolortransform
%{_bindir}/pfscut
%{_bindir}/pfsdisplayfunction
%{_bindir}/pfsextractchannels
%{_bindir}/pfsflip
%{_bindir}/pfsgamma
%{_bindir}/pfsin
%{_bindir}/pfsindcraw
%{_bindir}/pfsinpfm
%{_bindir}/pfsinppm
%{_bindir}/pfsinrgbe
%{_bindir}/pfsintiff
%{_bindir}/pfsinyuv
%{_bindir}/pfsout
%{_bindir}/pfsouthdrhtml
%{_bindir}/pfsoutpfm
%{_bindir}/pfsoutppm
%{_bindir}/pfsoutrgbe
%{_bindir}/pfsouttiff
%{_bindir}/pfsoutyuv
%{_bindir}/pfspad
%{_bindir}/pfspanoramic
%{_bindir}/pfsretime
%{_bindir}/pfsrotate
%{_bindir}/pfssize
%{_bindir}/pfstag
%{_datadir}/pfstools/hdrhtml_c_b2.csv
%{_datadir}/pfstools/hdrhtml_c_b3.csv
%{_datadir}/pfstools/hdrhtml_c_b4.csv
%{_datadir}/pfstools/hdrhtml_c_b5.csv
%{_datadir}/pfstools/hdrhtml_default_templ/
%{_datadir}/pfstools/hdrhtml_hdrlabs_templ/
%{_datadir}/pfstools/hdrhtml_t_b2.csv
%{_datadir}/pfstools/hdrhtml_t_b3.csv
%{_datadir}/pfstools/hdrhtml_t_b4.csv
%{_datadir}/pfstools/hdrhtml_t_b5.csv
%{_mandir}/man1/pfsabsolute.1%{?ext_man}
%{_mandir}/man1/pfscat.1%{?ext_man}
%{_mandir}/man1/pfsclamp.1%{?ext_man}
%{_mandir}/man1/pfscolortransform.1%{?ext_man}
%{_mandir}/man1/pfscut.1%{?ext_man}
%{_mandir}/man1/pfsdisplayfunction.1%{?ext_man}
%{_mandir}/man1/pfsextractchannels.1%{?ext_man}
%{_mandir}/man1/pfsflip.1%{?ext_man}
%{_mandir}/man1/pfsgamma.1%{?ext_man}
%{_mandir}/man1/pfsin.1%{?ext_man}
%{_mandir}/man1/pfsindcraw.1%{?ext_man}
%{_mandir}/man1/pfsinpfm.1%{?ext_man}
%{_mandir}/man1/pfsinppm.1%{?ext_man}
%{_mandir}/man1/pfsinrgbe.1%{?ext_man}
%{_mandir}/man1/pfsintiff.1%{?ext_man}
%{_mandir}/man1/pfsinyuv.1%{?ext_man}
%{_mandir}/man1/pfsout.1%{?ext_man}
%{_mandir}/man1/pfsouthdrhtml.1%{?ext_man}
%{_mandir}/man1/pfsoutpfm.1%{?ext_man}
%{_mandir}/man1/pfsoutppm.1%{?ext_man}
%{_mandir}/man1/pfsoutrgbe.1%{?ext_man}
%{_mandir}/man1/pfsouttiff.1%{?ext_man}
%{_mandir}/man1/pfsoutyuv.1%{?ext_man}
%{_mandir}/man1/pfspad.1%{?ext_man}
%{_mandir}/man1/pfspanoramic.1%{?ext_man}
%{_mandir}/man1/pfsretime.1%{?ext_man}
%{_mandir}/man1/pfsrotate.1%{?ext_man}
%{_mandir}/man1/pfssize.1%{?ext_man}
%{_mandir}/man1/pfstag.1%{?ext_man}

%files -n %{_libname}
%{_libdir}/libpfs.so.*

%files devel
%doc doc/faq.txt
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libpfs.so

#Disabled until we can renable opencv
#%%files -n pfscalign
#%%{_bindir}/pfsalign
#%%{_mandir}/man1/pfsalign%%{ext_man}

%files -n pfscalibration
%{_bindir}/dcraw2hdrgen
%{_bindir}/jpeg2hdrgen
%{_bindir}/pfshdrcalibrate
%{_bindir}/pfsinhdrgen
%{_bindir}/pfsinme
%{_bindir}/pfsplotresponse
%{_mandir}/man1/dcraw2hdrgen.1%{?ext_man}
%{_mandir}/man1/jpeg2hdrgen.1%{?ext_man}
%{_mandir}/man1/pfshdrcalibrate.1%{?ext_man}
%{_mandir}/man1/pfsinhdrgen.1%{?ext_man}
%{_mandir}/man1/pfsinme.1%{?ext_man}
%{_mandir}/man1/pfsplotresponse.1%{?ext_man}

%files -n pfstmo
%{_bindir}/pfstmo_drago03
%{_bindir}/pfstmo_durand02
%{_bindir}/pfstmo_fattal02
%{_bindir}/pfstmo_ferradans11
%{_bindir}/pfstmo_mai11
%{_bindir}/pfstmo_mantiuk06
%{_bindir}/pfstmo_mantiuk08
%{_bindir}/pfstmo_pattanaik00
%{_bindir}/pfstmo_reinhard02
%{_bindir}/pfstmo_reinhard05
%{_mandir}/man1/pfstmo_drago03.1%{?ext_man}
%{_mandir}/man1/pfstmo_durand02.1%{?ext_man}
%{_mandir}/man1/pfstmo_fattal02.1%{?ext_man}
%{_mandir}/man1/pfstmo_ferradans11.1%{?ext_man}
%{_mandir}/man1/pfstmo_mai11.1%{?ext_man}
%{_mandir}/man1/pfstmo_mantiuk06.1%{?ext_man}
%{_mandir}/man1/pfstmo_mantiuk08.1%{?ext_man}
%{_mandir}/man1/pfstmo_pattanaik00.1%{?ext_man}
%{_mandir}/man1/pfstmo_reinhard02.1%{?ext_man}
%{_mandir}/man1/pfstmo_reinhard05.1%{?ext_man}

%files -n pfsview
%{_bindir}/pfsv
%{_bindir}/pfsview
%{_mandir}/man1/pfsview.1%{?ext_man}

%files -n pfsglview
%{_bindir}/pfsglview
%{_mandir}/man1/pfsglview.1%{?ext_man}

%files exr
%{_bindir}/pfsinexr
%{_bindir}/pfsoutexr
%{_mandir}/man1/pfsinexr.1%{?ext_man}
%{_mandir}/man1/pfsoutexr.1%{?ext_man}

%files imgmagick
%{_bindir}/pfsinimgmagick
%{_bindir}/pfsoutimgmagick
%{_mandir}/man1/pfsinimgmagick.1%{?ext_man}
%{_mandir}/man1/pfsoutimgmagick.1%{?ext_man}

%files octave
%dir %{_libdir}/octave/*/site
%dir %{_libdir}/octave/*/site/oct
%dir %{_libdir}/octave/*/site/oct/*/
%{_bindir}/pfsoctavelum
%{_bindir}/pfsoctavergb
%{_bindir}/pfsstat
%{_datadir}/octave/*/site/m/pfstools/
%{_libdir}/octave/*/site/oct/*/pfstools/
%{_mandir}/man1/pfsoctavelum.1%{?ext_man}
%{_mandir}/man1/pfsoctavergb.1%{?ext_man}
%{_mandir}/man1/pfsstat.1%{?ext_man}

%changelog
* Wed Mar 11 2020 Christophe Giboudeaux <christophe@krop.fr>
- Require freeglut-devel instead of pkgconfig(freeglut).
  The pkgconfig name changed in Tumbleweed.
* Wed Jan 23 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Correct pfstools-fix-libpfs-linkage.patch
  * Fix broken octave binary modules - mkoctfile does not specify
  - Wl,--no-undefined, and modules fail at runtime:
    ".../pfsget.oct: undefined symbol: _ZN3pfs5DOMIOD1Ev"
  * Fix random parallel build failures due to missing make dependency
* Tue Oct 16 2018 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.1.0:
  * Added support for .yuv files encoded as PQ2020 or HLG2020
  * Use Qt5 instead of Qt4
- Update the URL
- Refresh patches, use %%autosetup -p1
- Drop pfstools-Qt5.patch. Fixed upstream.
- Run spec-cleaner
- Refresh pfstools-1.8.1-fix-return-in-nonvoid.patch to handle more
  cases.
* Wed Sep  6 2017 aloisio@gmx.com
- Update to version 2.0.6
  * Fixed: --frame frame range spec can now handle negative frame
    order, e.g. 30:-1:0
  * Added: Added photon-noise weighting in pfshdrcalibrate - very
    small improvement for some images
  * Fixed: pfsview does not change zoom settings when flipping
    between next/previous images
  * Fixed: Fixed bug in pfsin/outimgmagics - missing call to
    InitializeMagick causing assertion fault
  * Fixed: Fixed bug in pfsouthdrhtml - missing call to
    InitializeMagick causing assertion fault
  * Added: Matlab MEX files can now be compiled on Windows from
    Cygwin using VisualStudio compiler
  version 2.0.5:
  * fixed: pfsinppm now can read multiple frames using --frames
    but also from a ppm file
  * fixed: a few typos in the documentation and code (thanks to
    Andreas)
  * fixed: fixed octave interface to work with Octave 3.8.1 (and
    hopefully later versions)
  * fixed: octave-config used to automatically determine were to
    install Octave files
  * fixed: compilation issues with c++-11
  * fixed: bug in the assert statement made some matlab mex
    functions to crash (in debug mode)
  * fixed: version number string is now correctly reported
  * fixed: reverts mistakenly introduced fix from 2.0.0: pfsinpfm
    and pfsoutpfm do not flip images (top-bottom)
  * fixed: pfs handles now very long tags (by truncating them)
- Refreshed pfstools-octinstall.patch
- Dropped pfstools-maptype.patch (no longer necessary)
- Added pfstools-Qt5.patch to build against Qt5 libs.
- Spec cleanup
* Fri Apr  7 2017 jengelh@inai.de
- Grammatical corrections to descriptions.
- Replace %%__-type indirect macros.
* Tue Mar 28 2017 pgajdos@suse.com
- build also with ImageMagick-7
  + pfstools-ImageMagick7.patch
* Mon Mar 14 2016 plinnell@opensuse.org
- Disable pfscalign subpackage to fix build. It depends on non-free
  opencv
* Sun Mar 13 2016 idonmez@suse.com
- Disable opencv support because it depends on non-free part.
* Thu Dec 17 2015 p.drouand@gmail.com
- Fix octave dependency
* Thu Sep 17 2015 p.drouand@gmail.com
- Update to version 2.0.4
  * fixed: added installation of octave-based scripts: pfsoctavelum
    pfsoctavergb pfsstat
  * fixed: libraries installed in lib64 if needed
  * fixed: added "so" version to the pfs.so library
  * fixed: Replaced depreciated OctaveMap for compatibility with octave 4.0.0
- Changes from version 2.0.0
  * added: Starting from pfstools 2.0.0, pfstmo and pfscalibration
    are included in the pfstools source package
  * changed: support for automake dropped in favour of cmake
  * fixed: pfsinpfm and pfsoutpfm now handle both big and little endian
    files correctly
  * fixed: pfsinpfm and pfsoutpfm do not flip images (top-bottom)
  * added: new tone-mapping operator: pfstmo_mai11
  * changed: Thoroughly updated README files
  * fixed: several issues with octave scripts (compatibility with newer
    Octave releases), in particular pfs_write_rgb
- Add dependencies following upstream changes
  * cmake
  * doxygen
  * gsl-devel
  * hdf5-devel
  * opencv-devel
  * fftw3-threads-devel instead of fftw3-devel
  * opencv-devel
  * pkgconfig(libexif)
- Re-enable building against octave
- Split out some tools into their own packages
  * libpfs-2
  * pfscalign
  * pfscalibration
  * pfstmo
  * pfsview
  * pfsglview
  * pfstools-exr
  * pfstools-imgmagick
  * pfstools-octave
- Remove obsolete patches
  * pfstools-octave.patch
  * pfstools-stringcompare.patch
  * pfstools-no-debug-mangling.patch
- Added patches
  * pfstools-maptype.patch
  * pfstools-octinstall.patch
  * pfstools-fix-libpfs-linkage.patch
* Mon Apr 22 2013 dimstar@opensuse.org
- Add pfstools-no-debug-mangling.patch: don't drop occurences of
  "-g" from CFLAGS. It destroys -grecord-gcc-flags.
* Tue Sep 18 2012 idonmez@suse.com
- Add explicit build dependency on glu
* Sat May 12 2012 anixx@opensuse.org
- fix build by correcting the build dependency on libMagick++-devel
* Tue Mar  6 2012 tabraham@novell.com
- refreshed pfstools-octave.patch
- Update to version 1.8.4
  * fixed: SegFault from pfsview when switching channels
  * fixed: quoted arguments in pfsin/pfsout/pfsv/pfsindcraw/
    pfsinmulti (fixes bug 3279342)
- Changes from version 1.8.3
  * fixed: pfsdisplayfunction properly interpolates display LUT
  * fixed: bug #3080304 - configure uses non-portable test(1) syntax
  * fixed: bug #1766263 - pfsinhdrgen fails silently on pfsin
    failure. - partially
  * fixed: pfsview the entire code converted from qt3 to qt4 (fixes
    bug #3127946)
  * fixed: "Fit window to content" works again in pfsview
  * added: window icon in pfsview
  * added: improved image file saving in pfsview
- Changes from version 1.8.2
  * fixed: compiler incompatibility issue in pfspanoramic.cpp
  * fixed: bug #2953028 "gcc 4.4.1 const cast error"
  * fixed: spaces were improperly escaped in pfsin / pfsout (thanks
    to Timo)
  * added: new improved hdrhtml template from hdrlabs.com (thanks
    to Christian)
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Mar  2 2010 puzel@novell.com
- add pfstools-1.8.1-fix-return-in-nonvoid.patch
* Thu Aug  6 2009 postadal@suse.cz
- updated to version 1.8.1
  * pfsouthdrhtml for generating web pages with an HDR viewer
  * pfsview shows in the status bar current exposure for the dynamic
    range window (relative to Y=1)
- updated pfstools-gcc.patch (bnc#445426)
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Sun Sep  7 2008 postadal@suse.cz
- updated to version 1.6.5
  * mostly improvements in the matlab interface (thanks to Neil
    Alldrin). Also two patches ported from Debian (dcraw and octave3.0)
* Mon Apr 14 2008 postadal@suse.cz
- updated to version 1.6.4
  * fixed: pfsinopenexr can now read files that has data window < display window
  * fixed: pfs library can handle channel names up to 32 characters (was 8)
  * updated: pfs specification - max string lengths and format of custom channel names
  * security fix: fscanf in rgbeio.cpp (thanks to Stefan and Ludwig)
  * bugfix: pfsview - segfault when switching channels
  * fixed: pfsview - color readout in the status line refreshed when new channel
    or frame loaded
  * added: matlab/pfs_write_luminance.m
  * bugfix: rgbeio - header read properly when the first byte is 0x20
  * bugfix: rgbeio - fix misinterpreted rle-compresses lines
  * fixed: buffer overflow vulnerability in rgbeio.cpp
  * fixed: compilation issues with gcc-4.3 - missing includes
- removed obsoleted patch secfix_298770.patch
* Wed Dec  5 2007 nadvornik@suse.cz
- fixed includes for gcc 4.3 (stdlib.patch)
* Tue Aug 14 2007 postadal@suse.cz
- fixed vulnerability when reading Radiance RGBE (*.hdr) files
  [#298770] (secfix_298770.patch)
* Thu Aug  9 2007 ro@suse.de
- added libnetpbm-devel to buildreq
* Mon Aug  6 2007 postadal@suse.cz
- updated to version 1.6.1
  * bug-fix release, with a major fix for the sRGB color transform
- temporary removed octave support (changed octave API)
* Mon Jun 11 2007 ro@suse.de
- avoid stringcompare with char literal
* Tue Jun  5 2007 ro@suse.de
- added octave-devel to buildreq
* Mon May  7 2007 postadal@suse.cz
- updated to version 1.6.1
  * improved image readers/writes can load LDR images with the alpha channel
  * pfsglview - new OpenGL HDR viewer
  * pfsindcraw - dcraw integration
- added dcraw to requires
- run ldconfig
* Thu Feb  8 2007 ro@suse.de
- added defattr to devel package
* Mon Feb  5 2007 ro@suse.de
- run full autoreconf to fix build on x86_64
* Thu Dec 21 2006 ro@suse.de
- fix configure arguments and such prevent rpath for //usr/lib
* Fri Oct 27 2006 postadal@suse.cz
- added ImageMagick*-devel to BuildRequires (for pfs[in/out]imgmagick)
* Mon Oct 23 2006 postadal@suse.cz
- fixed invalid pure specifier (gcc.patch)
* Wed Oct 11 2006 postadal@suse.cz
- packed pfs_format_spec.pdf and faq.txt to -devel
* Sat Oct  7 2006 postadal@suse.cz
- initial version 1.5
- fixed linking octave (octave.patch)
- fixed gcc issues (gcc.patch)
